@@ -92,6 +92,7 @@ enum
 	TYPE_CTC,
 	TYPE_IUCV,
 	TYPE_QETH,
+	TYPE_VIRTIO,
 }
 type = TYPE_NONE;
 
@@ -303,6 +304,8 @@ static enum state_wanted get_networktype (void)
 		type = TYPE_CTC;
 	else if (!strncmp (ptr, "iucv", 4))
 		type = TYPE_IUCV;
+	else if (!strncmp (ptr, "virtio", 6))
+		type = TYPE_VIRTIO;
 	else
 		return WANT_ERROR;
 
@@ -555,9 +558,9 @@ static enum state_wanted confirm_qeth (void)
 	int ret;
 	char *ptr;
 
-	debconf_subst (client, template, "device0", device_current->ctc.channels[0]->name);
-	debconf_subst (client, template, "device1", device_current->ctc.channels[1]->name);
-	debconf_subst (client, template, "device2", device_current->ctc.channels[2]->name);
+	debconf_subst (client, template, "device0", device_current->qeth.channels[0]->name);
+	debconf_subst (client, template, "device1", device_current->qeth.channels[1]->name);
+	debconf_subst (client, template, "device2", device_current->qeth.channels[2]->name);
 
 	debconf_set (client, template, "true");
 	ret = my_debconf_input ("medium", template, &ptr);
@@ -830,6 +833,10 @@ int main (int argc __attribute__ ((unused)), char *argv[] __attribute__ ((unused
 							case TYPE_IUCV:
 								state = GET_IUCV_DEVICE;
 								break;
+							case TYPE_VIRTIO:
+								// no further configuration needed
+								state = FINISH;
+								break;
 							default:
 								state = ERROR;
 						}
